@@ -1,9 +1,11 @@
 #!/bin/env python
 
-from utils.utils import man_cq, get_cq
 import sys
+
+from utils.utils import man_cq, get_cq
 from utils.utils import get_brightness
-from .logger import log, set_log_file
+from .logger import log
+
 
 def boost(command: str, brightness, b_limit, b_range, new_cq=0):
     """Based on average brightness of video decrease(boost) Quantize value for encoding."""
@@ -24,6 +26,7 @@ def boost(command: str, brightness, b_limit, b_range, new_cq=0):
         _, _, exc_tb = sys.exc_info()
         print(f'Error in encoding loop {e}\nAt line {exc_tb.tb_lineno}')
 
+
 def boosting(bl, br, source, commands, passes):
     try:
         brightness = get_brightness(source.absolute().as_posix())
@@ -33,10 +36,10 @@ def boosting(bl, br, source, commands, passes):
             com1, _ = boost(commands[1], brightness, bl, br, new_cq=cq)
             commands = (com0, com1) + commands[2:]
         else:
-            commands = com0 + commands[1:]
-        log(f'{source.name}\n[Boost]\nAvg brightness: {br}\nAdjusted CQ: {cq}\n\n')
-        return commands, cq
+            commands = (com0,) + commands[1:]
+        log(f'{source.name}\n[Boost]\nAvg brightness: {brightness}\nAdjusted CQ: {cq}\n\n')
+        return commands
 
     except Exception as e:
         _, _, exc_tb = sys.exc_info()
-        print(f'Error in encoding loop {e}\nAt line {exc_tb.tb_lineno}')
\ No newline at end of file
+        print(f'Error in encoding loop {e}\nAt line {exc_tb.tb_lineno}')
