@@ -1,7 +1,10 @@
-#!/usr/bin/env python3
+#!/bin/env python
+
 import time
 from pathlib import Path
 import sys
+
+
 class Logger():
     def __init__(self):
         self.set_file = False
@@ -14,20 +17,22 @@ class Logger():
         if self.set_file:
             with open(self.set_file, 'a') as log:
                 log.write(time.strftime('%X') + ' ' + info)
+
+
 # Creating logger
 l = Logger()
-set_log_file = l.set_path
+log_file = l.set_path
 log = l.log
 
 
-def set_logging(log_path: Path, temp):
-        """Setting logging file location"""
-        if log_path:
-            log_path = Path(log_path)
-            if log_path.suffix == '':
-                log_path = log_path.with_suffix('.log')
-            set_log_file(log_path)
-        else:
-            set_log_file(temp / 'log.log')
+def set_log(log_path: Path, temp):
+    """Setting logging file location"""
+    if log_path:
+        log_path = Path(log_path)
+        if log_path.suffix == '':
+            log_path = log_path.with_suffix('.log')
+        log_file(log_path)
+    else:
+        log_file(temp / 'log.log')
 
-        log(f"Av1an Started\nCommand:\n{' '.join(sys.argv)}\n")
\ No newline at end of file
+    log(f"\nAv1an Started\nCommand:\n{' '.join(sys.argv)}\n")
